==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WrapperExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
/**
 * @hidden
 */
export let WrapperExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WrapperExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WrapperExpressionDescriptionMetadata.a == null) {
                WrapperExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WrapperExpressionDescriptionMetadata.c(WrapperExpressionDescriptionMetadata.a);
            }
            if (a.k(WrapperExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(WrapperExpressionDescriptionMetadata.a);
            FilterExpressionDescriptionMetadata.d(a);
        }
        static c(a) {
            FilterExpressionDescriptionMetadata.c(a);
            a.item("InnerExpression", "ExportedType:IFilterExpression");
            a.item("Expression", "ExportedType:FilterExpression");
            a.item("PropertyName", "String");
        }
        static d(a) {
            WrapperExpressionDescriptionMetadata.b(a);
            a.ac("WrapperExpression", WrapperExpressionDescriptionMetadata.a);
        }
    }
    WrapperExpressionDescriptionMetadata.$t = markType(WrapperExpressionDescriptionMetadata, 'WrapperExpressionDescriptionMetadata');
    WrapperExpressionDescriptionMetadata.a = null;
    return WrapperExpressionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WrapperExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
/**
 * @hidden
 */
export let WrapperExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WrapperExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (WrapperExpressionDescriptionMetadata.a == null) {
                WrapperExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WrapperExpressionDescriptionMetadata.c(WrapperExpressionDescriptionMetadata.a);
            }
            if (a.k(WrapperExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(WrapperExpressionDescriptionMetadata.a);
            FilterExpressionDescriptionMetadata.d(a);
        }
        static c(a) {
            FilterExpressionDescriptionMetadata.c(a);
            a.item("InnerExpression", "ExportedType:IFilterExpression");
            a.item("Expression", "ExportedType:FilterExpression");
            a.item("PropertyName", "String");
        }
        static d(a) {
            WrapperExpressionDescriptionMetadata.b(a);
            a.ad("WrapperExpression", WrapperExpressionDescriptionMetadata.a);
        }
    }
    WrapperExpressionDescriptionMetadata.$t = markType(WrapperExpressionDescriptionMetadata, 'WrapperExpressionDescriptionMetadata');
    WrapperExpressionDescriptionMetadata.a = null;
    return WrapperExpressionDescriptionMetadata;
})();
